const St = imports.gi.St;
const Main = imports.ui.main;
const Mainloop = imports.mainloop;
const Lang = imports.lang;
const GLib = imports.gi.GLib;
const Gio = imports.gi.Gio;

const timerVal = 2000;

let cpuMemInfo;
let meta;

function CpuMemInfo()
{   
    CpuMemInfo.prototype.construct = function()
    {
        this.iconMem = new St.Icon(
        {
	    gicon: Gio.icon_new_for_string(meta.path + "/memory.png"),
	    icon_type: St.IconType.SYMBOLIC,
	    icon_size: 16,
        });

	this.labelMem = new St.Label({
	    style_class: 'text'
	});

        this.iconCpu = new St.Icon(
        {
	    gicon: Gio.icon_new_for_string(meta.path + "/processor.png"),
	    icon_type: St.IconType.SYMBOLIC,
	    icon_size: 16,
        });

	this.labelCpu = new St.Label({
	    style_class: 'text'
	});

	this.box = new St.BoxLayout();
        this.box.add_actor(this.iconCpu);
        this.box.add_actor(this.labelCpu);
        this.box.add_actor(this.iconMem);
        this.box.add_actor(this.labelMem);
	Main.panel._rightBox.insert_actor(this.box, 0);

	this.timer = Mainloop.timeout_add(timerVal, Lang.bind(this, this.update));
	this.update();
    }

    CpuMemInfo.prototype.destruct = function()
    {
	Main.panel._rightBox.remove_actor(this.button);

        Mainloop.source_remove(this.timer);
    }

    CpuMemInfo.prototype.update = function()
    {
	let cpuTotal = 0, cpuIdle;

	let fileStat = GLib.file_get_contents('/proc/stat');
        linesStat = ("" + fileStat[1]).split("\n");

        for (let i = 0; i < linesStat.length; i++)
	{
            let values;

            if (linesStat[i].match(/^cpu /))
            {
                values = linesStat[i].match(/^cpu\s*(.*)$/)[1].split(' ');

		cpuIdle = values[3];

		for (let i = 0; i < values.length; i++)
		    cpuTotal += parseInt(values[i]);
            }
	}

	if (typeof(this.cpuTotalOld) == "undefined" && typeof(this.cpuIdleOld) == "undefined")
	{
	    this.cpuTotalOld = cpuTotal - 1;
	    this.cpuIdleOld = cpuIdle - 1;
	}

	let diffCpuTotal = cpuTotal - this.cpuTotalOld;
	let diffCpuIdle = cpuIdle - this.cpuIdleOld;

	let cpuValue = Math.round(100 * (diffCpuTotal - diffCpuIdle) / diffCpuTotal);

	this.cpuTotalOld = cpuTotal;
	this.cpuIdleOld = cpuIdle;

        this.labelCpu.set_text(cpuValue + " %");



	let memTotal, memFree, memBuffers, memCached;

	let fileMeminfo = GLib.file_get_contents('/proc/meminfo');
	linesMeminfo = ("" + fileMeminfo[1]).split("\n");

	for (let i = 0; i < linesMeminfo.length; i++)
	{
	    let values;

	    if (linesMeminfo[i].match(/^MemTotal/))
	    {
		values = linesMeminfo[i].match(/^MemTotal:\s*([^ ]*)\s*([^ ]*)$/);
		
		memTotal = values[1];
	    }
	    else if (linesMeminfo[i].match(/^MemFree/))
	    {
		values = linesMeminfo[i].match(/^MemFree:\s*([^ ]*)\s*([^ ]*)$/);
		
		memFree = values[1];
	    }
	    else if (linesMeminfo[i].match(/^Buffers/))
	    {
		values = linesMeminfo[i].match(/^Buffers:\s*([^ ]*)\s*([^ ]*)$/);
		
		memBuffers = values[1];
	    }
	    else if (linesMeminfo[i].match(/^Cached/))
	    {
		values = linesMeminfo[i].match(/^Cached:\s*([^ ]*)\s*([^ ]*)$/);
		
		memCached = values[1];
	    }	    
        }

	let memUsed = memTotal - memFree - memBuffers - memCached;
	memUsed = Math.round(memUsed / 1024);
	memTotal = Math.round(memTotal / 1024);

        this.labelMem.set_text(memUsed + " / " + memTotal + " Mo");

	return true;
    }

    this.construct();
}

function init(extensionMeta)
{
    meta = extensionMeta;
}

function enable()
{
    cpuMemInfo = new CpuMemInfo();
}

function disable()
{
    cpuMemInfo.destruct();
}
